@@ -1,5 +1,5 @@
 package AnyEvent::Handle::UDP;
-$AnyEvent::Handle::UDP::VERSION = '0.046';
+$AnyEvent::Handle::UDP::VERSION = '0.047';
 use strict;
 use warnings;
 
@@ -233,7 +233,7 @@ sub _on_addr {
 sub _error {
 	my ($self, $fatal, $message) = @_;
 
-	if (exists $self->{error_handler}) {
+	if (exists $self->{on_error}) {
 		$self->{on_error}->($self, $fatal, $message);
 		$self->destroy if $fatal;
 	} else {
@@ -315,7 +315,7 @@ AnyEvent::Handle::UDP - client/server UDP handles for AnyEvent
 
 =head1 VERSION
 
-version 0.046
+version 0.047
 
 =head1 SYNOPSIS
 
